==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/cn/vcn43.cpp <==
/*
  -----------------------------------------------------------------------------

  module: vcn43.cpp

  -----------------------------------------------------------------------------

  responsible:  BerndV

  special area: DBMServer Dbanalyzer Access

  description:  DBMServer Dbanalyzer Access - Implementation

  -----------------------------------------------------------------------------


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

/*
  -----------------------------------------------------------------------------
  includes
  -----------------------------------------------------------------------------
 */
#include "hcn43.h"
#include "hcn40.h"
#include "hcn50.h"
#include "hcn51.h"
#include "hcn90.h"

#include "SAPDB/ToolsCommon/Tools_System.hpp"

#define DBA_STATE  "dbanalyzer -d %s -u %s,%s -state"
#define DBA_STOP   "dbanalyzer -d %s -u %s,%s -stop"
#define DBA_DELETE "dbanalyzer -d %s -u %s,%s -delete %s"
 
#ifdef _WIN32
  #define DBA_START      "start /B dbanalyzer -d %s -u %s,%s %s"
#else
  #define DBA_START      "dbanalyzer -d %s -u %s,%s %s &"
#endif


/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerStart
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerStart
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];
  int            nCounter = 0;

  cn51DBMConfigValue  cfgDBAUsr(vcontrol->dbname, CFG_DBAUSR_CN51);
  cn50DBMUser         oUser(vcontrol->dbname, (tsp00_Namec) cfgDBAUsr );

  sprintf(szCommand, DBA_STATE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
  sprintf(szDummy,   DBA_STATE, vcontrol->dbname.asCharp(), "*",  "*");
  nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
  if (nFuncReturn == OK_CN00 && (strstr(replyData, "INFO 20:") != NULL)) {
    sprintf(szCommand, DBA_START, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp(), command->args);
    sprintf(szDummy,   DBA_START, vcontrol->dbname.asCharp(), "*",  "*", command->args);
    nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
    if (nFuncReturn == OK_CN00) {
      sprintf(szCommand, DBA_STATE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
      sprintf(szDummy,   DBA_STATE, vcontrol->dbname.asCharp(), "*",  "*");
      ToolsSys_sleep(2);
      nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
      while ((nFuncReturn == OK_CN00) && (strstr(replyData, "INFO 20:") != NULL) && (nCounter < 3)) {
        ++nCounter;
        ToolsSys_sleep(2);
        nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
      } // end while
    } // end if
  } // end if
  return nFuncReturn;
} // end cn43DBanalyzerStart

/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerStop
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerStop
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];

  cn51DBMConfigValue  cfgDBAUsr(vcontrol->dbname, CFG_DBAUSR_CN51);
  cn50DBMUser         oUser(vcontrol->dbname, (tsp00_Namec) cfgDBAUsr );

  sprintf(szCommand, DBA_STOP, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
  sprintf(szDummy,   DBA_STOP, vcontrol->dbname.asCharp(), "*",  "*");

  return cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
} // end cn43DBanalyzerStop

/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerState
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerState
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];

  cn51DBMConfigValue  cfgDBAUsr(vcontrol->dbname, CFG_DBAUSR_CN51);
  cn50DBMUser         oUser(vcontrol->dbname, (tsp00_Namec) cfgDBAUsr );

  sprintf(szCommand, DBA_STATE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
  sprintf(szDummy,   DBA_STATE, vcontrol->dbname.asCharp(), "*",  "*");

  return cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
} // end cn43DBanalyzerState

/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerDelete
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerDelete
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];

  cn51DBMConfigValue  cfgDBAUsr(vcontrol->dbname, CFG_DBAUSR_CN51);
  cn50DBMUser         oUser(vcontrol->dbname, (tsp00_Namec) cfgDBAUsr );

  sprintf(szCommand, DBA_DELETE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp(), command->args);
  sprintf(szDummy,   DBA_DELETE, vcontrol->dbname.asCharp(), "*",  "*", command->args);

  return cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
} // end cn43DBanalyzerDelete

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/cn/vcn43.cpp <==
/*
  -----------------------------------------------------------------------------

  module: vcn43.cpp

  -----------------------------------------------------------------------------

  responsible:  BerndV

  special area: DBMServer Dbanalyzer Access

  description:  DBMServer Dbanalyzer Access - Implementation

  -----------------------------------------------------------------------------


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

/*
  -----------------------------------------------------------------------------
  includes
  -----------------------------------------------------------------------------
 */
#include "hcn43.h"
#include "hcn40.h"
#include "hcn50.h"
#include "hcn90.h"

#include "SAPDB/ToolsCommon/Tools_System.hpp"

#define DBA_STATE  "dbanalyzer -d %s -u %s,%s -state"
#define DBA_STOP   "dbanalyzer -d %s -u %s,%s -stop"
#define DBA_DELETE "dbanalyzer -d %s -u %s,%s -delete %s"
 
#ifdef _WIN32
  #define DBA_START      "start /B dbanalyzer -d %s -u %s,%s %s"
#else
  #define DBA_START      "dbanalyzer -d %s -u %s,%s %s &"
#endif


/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerStart
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerStart
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];
  int            nCounter = 0;

  if (cn90DBState(vcontrol->dbname) != STATE_WARM_CN00) {
    nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBNORUN_CN00);
  } // end if

  if (nFuncReturn == OK_CN00) {
    cn50DBMUser    oUser (vcontrol->dbname, cn50DBMUser::getSYSDBA(vcontrol->dbname));

    if (oUser.lastEvent()) {
      nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBAUNKNOWN_CN00);
    } // end if

    if (nFuncReturn == OK_CN00) {
      sprintf(szCommand, DBA_STATE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
      sprintf(szDummy,   DBA_STATE, vcontrol->dbname.asCharp(), "*",  "*");
      nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
      if (nFuncReturn == OK_CN00 && (strstr(replyData, "INFO 20:") != NULL)) {
        sprintf(szCommand, DBA_START, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp(), command->args);
        sprintf(szDummy,   DBA_START, vcontrol->dbname.asCharp(), "*",  "*", command->args);
        nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
        if (nFuncReturn == OK_CN00) {
          sprintf(szCommand, DBA_STATE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
          sprintf(szDummy,   DBA_STATE, vcontrol->dbname.asCharp(), "*",  "*");
          ToolsSys_sleep(2);
          nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
          while ((nFuncReturn == OK_CN00) && (strstr(replyData, "INFO 20:") != NULL) && (nCounter < 3)) {
            ++nCounter;
            ToolsSys_sleep(2);
            nFuncReturn =  cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
          } // end while
        } // end if
      } // end if
    } // end if
  } // end if

  return nFuncReturn;
} // end cn43DBanalyzerStart

/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerStop
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerStop
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];

  if (cn90DBState(vcontrol->dbname) != STATE_WARM_CN00) {
    nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBNORUN_CN00);
  } // end if

  if (nFuncReturn == OK_CN00) {
    cn50DBMUser    oUser (vcontrol->dbname, cn50DBMUser::getSYSDBA(vcontrol->dbname));

    if (oUser.lastEvent()) {
      nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBAUNKNOWN_CN00);
    } // end if

    if (nFuncReturn == OK_CN00) {
      sprintf(szCommand, DBA_STOP, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
      sprintf(szDummy,   DBA_STOP, vcontrol->dbname.asCharp(), "*",  "*");
      nFuncReturn = cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
    } // end if
  } // end if

  return nFuncReturn;
} // end cn43DBanalyzerStop

/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerState
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerState
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];

  if (cn90DBState(vcontrol->dbname) != STATE_WARM_CN00) {
    nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBNORUN_CN00);
  } // end if

  if (nFuncReturn == OK_CN00) {
  cn50DBMUser    oUser (vcontrol->dbname, cn50DBMUser::getSYSDBA(vcontrol->dbname));

    if (oUser.lastEvent()) {
      nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBAUNKNOWN_CN00);
    } // end if

    if (nFuncReturn == OK_CN00) {
      sprintf(szCommand, DBA_STATE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp());
      sprintf(szDummy,   DBA_STATE, vcontrol->dbname.asCharp(), "*",  "*");
      nFuncReturn = cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
    } // end if
  } // end if

  return nFuncReturn;
} // end cn43DBanalyzerState

/*
  -----------------------------------------------------------------------------
  public function cn43DBanalyzerDelete
  -----------------------------------------------------------------------------
*/
tcn00_Error cn43DBanalyzerDelete
      ( VControlDataT * vcontrol,
        CommandT      * command,
        char          * replyData,
        int           * replyLen,
        int             replyLenMax)
{
  tcn00_Error    nFuncReturn = OK_CN00;
  char           szCommand [PARAMETER_MAXLEN_CN90];
  char           szDummy   [PARAMETER_MAXLEN_CN90];

  if (cn90DBState(vcontrol->dbname) != STATE_WARM_CN00) {
    nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBNORUN_CN00);
  } // end if

  if (nFuncReturn == OK_CN00) {
    cn50DBMUser    oUser (vcontrol->dbname, cn50DBMUser::getSYSDBA(vcontrol->dbname));

    if (oUser.lastEvent()) {
      nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_DBAUNKNOWN_CN00);
    } // end if

    if (nFuncReturn == OK_CN00) {
      sprintf(szCommand, DBA_DELETE, vcontrol->dbname.asCharp(), oUser.getUserName().asCharp(), oUser.getClearMasterPwd().asCharp(), command->args);
      sprintf(szDummy,   DBA_DELETE, vcontrol->dbname.asCharp(), "*",  "*", command->args);
      nFuncReturn = cn40ExecCommand(replyData, replyLen, replyLenMax, szCommand, szDummy);
    } // end if
  } // end if

  return nFuncReturn;
} // end cn43DBanalyzerDelete
